pub enum Rootwards {
MutatorAnnouncement {
connection_id: ChildConnectionId,
participant_id: ParticipantId,
mutator_id: MutatorId,
mutator_attrs: BTreeMap<AttrKey, AttrVal>,
},
MutatorRetirement {
connection_id: ChildConnectionId,
participant_id: ParticipantId,
mutator_id: MutatorId,
},
UpdateTriggerState {
connection_id: ChildConnectionId,
mutator_id: MutatorId,
mutation_id: MutationId,
maybe_trigger_crdt: Option<TriggerCRDT>,
},
}Expand description
Messages from an already-authenticated child connection.
Variants
MutatorAnnouncement
Fields

connection_id: ChildConnectionId
participant_id: ParticipantIdId of the participant in charge of managing the mutator
MutatorRetirement
Fields

connection_id: ChildConnectionId
participant_id: ParticipantIdId of the participant in charge of managing the mutator
UpdateTriggerState
Fields

connection_id: ChildConnectionId
mutation_id: MutationId
maybe_trigger_crdt: Option<TriggerCRDT>Interpret “None” as “clear your trigger state for this mutation, you don’t need to track it (anymore)”
Implementations
Sourceimpl Rootwards
impl Rootwards
pub fn connection_id(&self) -> ChildConnectionId